Origin

Trait Origin 

pub trait Origin: Sealed {
    type Request;
}
Where an IoContext came from. Sealed: the set of origins is closed to this crate. Request is the owned payload the context carries (() when there is none).

Required Associated Types

type Request

The owned request payload for this origin.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors